<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// S
	'svp_description' => 'Este plugin proporciona, por un lado, una API que permite efectuar búsquedas multi-criterio, recopilar y presentar información sobre los plugins (módulos funcionales, temas y esqueletos) y, por otro lado, una nueva interfaz de administración de los plugins que gestiona las dependencias entre ellos.',
	'svp_slogan' => 'Servidor de información y descarga de plugins',
];
